@@ -3,26 +3,54 @@
 # pylint: disable=invalid-name
 """Configuration of Sphinx documentation generator."""
 
-from pathlib import Path
+import os
 import sys
+from pathlib import Path
+
+# -- Path setup --------------------------------------------------------------
+
+PROJECT_ROOT_DIR = Path(__file__).parents[1].resolve()
+IS_RELEASE_ON_RTD = (
+    os.getenv('READTHEDOCS', 'False') == 'True'
+    and os.environ['READTHEDOCS_VERSION_TYPE'] == 'tag'
+)
+if IS_RELEASE_ON_RTD:
+    tags: set[str]
+    # pylint: disable-next=used-before-assignment
+    tags.add('is_release')  # noqa: F821
 
 
 # Make in-tree extension importable in non-tox setups/envs, like RTD.
 # Refs:
 # https://github.com/readthedocs/readthedocs.org/issues/6311
 # https://github.com/readthedocs/readthedocs.org/issues/7182
-sys.path.insert(0, str(Path(__file__).parent.resolve()))
+sys.path.insert(0, str(PROJECT_ROOT_DIR))
 
 
 extensions = [
     'sphinx.ext.autodoc',
+    'sphinx.ext.autosectionlabel',  # autocreate section targets for refs
+    'sphinx.ext.doctest',
     'sphinx.ext.extlinks',
     'sphinx.ext.intersphinx',
+    # Third-party extensions:
     'jaraco.packaging.sphinx',
     'sphinx_tabs.tabs',
     'sphinxcontrib.apidoc',
-    'sphinxcontrib.spelling',
-    'scm_tag_titles_ext',
+    'sphinxcontrib.towncrier.ext',  # provides `.. towncrier-draft-entries::`
+
+    # In-tree extensions:
+    'spelling_stub_ext',  # auto-loads `sphinxcontrib.spelling` if installed
+]
+
+# Add any paths that contain templates here, relative to this directory.
+templates_path = ['_templates']
+
+# List of patterns, relative to source directory, that match files and
+# directories to ignore when looking for source files.
+# This pattern also affects html_static_path and html_extra_path.
+exclude_patterns = [
+    'changelog-fragments.d/**',  # Towncrier-managed change notes
 ]
 
 master_doc = 'index'
@@ -48,11 +76,6 @@ spelling_word_list_filename = [
     'spelling_wordlist.txt',
 ]
 
-scm_version_title_settings = {
-    'scm': 'git',
-    'date_format': '%d %b %Y',
-}
-
 github_url = 'https://github.com'
 github_repo_org = 'cherrypy'
 github_repo_name = 'cheroot'
@@ -62,22 +85,27 @@ cp_github_repo_url = f'{github_url}/{github_repo_org}/cherrypy'
 github_sponsors_url = f'{github_url}/sponsors'
 
 extlinks = {
-    'issue': (f'{github_repo_url}/issues/%s', '#'),
-    'pr': (f'{github_repo_url}/pull/%s', 'PR #'),
-    'commit': (f'{github_repo_url}/commit/%s', ''),
-    'cp-issue': (f'{cp_github_repo_url}/issues/%s', 'CherryPy #'),
-    'cp-pr': (f'{cp_github_repo_url}/pull/%s', 'CherryPy PR #'),
-    'gh': (f'{github_url}/%s', 'GitHub: '),
-    'user': (f'{github_sponsors_url}/%s', '@'),
+    'issue': (f'{github_repo_url}/issues/%s', '#%s'),
+    'pr': (f'{github_repo_url}/pull/%s', 'PR #%s'),
+    'commit': (f'{github_repo_url}/commit/%s', '%s'),
+    'cp-issue': (f'{cp_github_repo_url}/issues/%s', 'CherryPy #%s'),
+    'cp-pr': (f'{cp_github_repo_url}/pull/%s', 'CherryPy PR #%s'),
+    'gh': (f'{github_url}/%s', 'GitHub: %s'),
+    'user': (f'{github_sponsors_url}/%s', '@%s'),
 }
 
 intersphinx_mapping = {
     'python': ('https://docs.python.org/3', None),
     'python2': ('https://docs.python.org/2', None),
-    'cherrypy': ('https://docs.cherrypy.org/en/latest/', None),
+    # Ref: https://github.com/cherrypy/cherrypy/issues/1872
+    'cherrypy': (
+        'https://docs.cherrypy.dev/en/latest',
+        ('https://cherrypy.rtfd.io/en/latest', None),
+    ),
     'trustme': ('https://trustme.readthedocs.io/en/latest/', None),
     'ddt': ('https://ddt.readthedocs.io/en/latest/', None),
     'pyopenssl': ('https://www.pyopenssl.org/en/latest/', None),
+    'towncrier': ('https://towncrier.rtfd.io/en/latest', None),
 }
 
 linkcheck_ignore = [
@@ -93,12 +121,23 @@ linkcheck_ignore = [
     r'https://github\.com/cherrypy/cherrypy/issues',
     r'https://github\.com/cherrypy/cherrypy/pull',
 
-    # Requires a more liberal 'Accept: ' HTTP request header:
-    # Ref: https://github.com/sphinx-doc/sphinx/issues/7247
-    r'https://github\.com/cherrypy/cheroot/workflows/[^/]+/badge\.svg',
+    # Has an ephemeral anchor (line-range) but actual HTML has separate per-
+    # line anchors.
+    r'https://github\.com'
+    r'/python/cpython/blob/c39b52f/Lib/poplib\.py#L297-L302',
+    r'https://github\.com'
+    r'/python/cpython/blob/c39b52f/Lib/poplib\.py#user-content-L297-L302',
+
+    r'^https://matrix\.to/#',  # these render fully on front-end from anchors
 ]
 linkcheck_workers = 25
 
+# -- Options for sphinx.ext.autosectionlabel extension -----------------------
+
+# Ref:
+# https://www.sphinx-doc.org/en/master/usage/extensions/autosectionlabel.html
+autosectionlabel_maxdepth = 1  # mitigate Towncrier nested subtitles collision
+
 nitpicky = True
 
 # NOTE: consider having a separate ignore file
@@ -109,8 +148,20 @@ nitpick_ignore = [
     ('py:class', '_pyio.BufferedReader'),
     ('py:class', 'unittest.case.TestCase'),
     ('py:meth', 'cheroot.connections.ConnectionManager.get_conn'),
+
+    # Ref: https://github.com/pyca/pyopenssl/issues/1012
+    ('py:class', 'pyopenssl:OpenSSL.SSL.Context'),
 ]
 
+# -- Options for towncrier_draft extension -----------------------------------
+
+# or: 'sphinx-version', 'sphinx-release'
+towncrier_draft_autoversion_mode = 'draft'
+towncrier_draft_include_empty = True
+towncrier_draft_working_directory = PROJECT_ROOT_DIR
+towncrier_draft_config_path = 'towncrier.toml'  # relative to cwd
+
+
 # Ref:
 # * https://github.com/djungelorm/sphinx-tabs/issues/26#issuecomment-422160463
 sphinx_tabs_valid_builders = ['linkcheck']  # prevent linkcheck warning
@@ -121,4 +172,4 @@ sphinx_tabs_valid_builders = ['linkcheck']  # prevent linkcheck warning
 default_role = 'any'
 
 
-html_theme = 'alabaster'
+html_theme = 'furo'
